@@ -12,8 +12,8 @@
 #' `copy_labels_from` is intended to be used with \pkg{dplyr} syntax,
 #' see examples.
 #'
-#' @param from A vector or a data.frame (or tibble) to copy labels from.
-#' @param to A vector or data.frame (or tibble) to copy labels to.
+#' @param from A vector or a data.frame (or survey design) to copy labels from.
+#' @param to A vector or data.frame (or survey design) to copy labels to.
 #' @param .strict When `from` is a labelled vector, `to` have to be of the same
 #' type (numeric or character) in order to copy value labels and SPSS-style
 #' missing values. If this is not the case and `.strict = TRUE`, an error
@@ -47,18 +47,10 @@ copy_labels <- function(from, to, .strict = TRUE) {
 
 #' @export
 copy_labels.default <- function(from, to, .strict = TRUE) {
-  if (!is.atomic(from)) {
-    stop("`from` should be a vector or a data.frame",
-      call. = FALSE,
-      domain = "R-labelled"
-    )
-  }
-  if (!is.atomic(to)) {
-    stop("`to` should be a vector",
-      call. = FALSE,
-      domain = "R-labelled"
-    )
-  }
+  if (!is.atomic(from))
+    cli::cli_abort("{.arg from} must be a vector or a data frame.")
+  if (!is.atomic(to))
+    cli::cli_abort("{.arg to} must be a vector.")
   var_label(to) <- var_label(from)
   to
 }
@@ -66,12 +58,13 @@ copy_labels.default <- function(from, to, .strict = TRUE) {
 
 #' @export
 copy_labels.haven_labelled <- function(from, to, .strict = TRUE) {
-  if (mode(from) != mode(to) && .strict) {
-    stop("`from` and `to` should be of same type",
-      call. = FALSE,
-      domain = "R-labelled"
+  if (mode(from) != mode(to) && .strict)
+    cli::cli_abort(
+      paste(
+        "{.arg from} ({class(from)}) and {.arg to} ({class(to)})",
+        "must be of same type."
+      )
     )
-  }
   var_label(to) <- var_label(from)
 
   if (mode(from) == mode(to)) {
@@ -84,17 +77,40 @@ copy_labels.haven_labelled <- function(from, to, .strict = TRUE) {
 
 #' @export
 copy_labels.data.frame <- function(from, to, .strict = TRUE) {
-  if (!is.data.frame(to)) {
-    stop("`to` should be a data frame", call. = FALSE, domain = "R-labelled")
-  }
-  for (var in names(to)) {
-    if (var %in% names(from)) {
-      to[[var]] <- copy_labels(from[[var]], to[[var]], .strict = .strict)
+  if (
+    !inherits(to, "data.frame") &&
+      !inherits(to, "survey.design") &&
+      !inherits(to, "svyrep.design")
+  )
+    cli::cli_abort("{.arg to} should be a data frame or a survey design.")
+
+  if (inherits(from, "survey.design") || inherits(from, "svyrep.design"))
+    from <- from$variables
+
+  if (inherits(to, "data.frame")) {
+    for (var in names(to)) {
+      if (var %in% names(from)) {
+        to[[var]] <- copy_labels(from[[var]], to[[var]], .strict = .strict)
+      }
+    }
+  } else { # survey design case
+    for (var in names(to$variables)) {
+      if (var %in% names(from)) {
+        to$variables[[var]] <-
+          copy_labels(from[[var]], to$variables[[var]], .strict = .strict)
+      }
     }
   }
+
   to
 }
 
+#' @export
+copy_labels.survey.design <- copy_labels.data.frame
+
+#' @export
+copy_labels.svyrep.design <- copy_labels.data.frame
+
 #' @rdname copy_labels
 #' @export
 copy_labels_from <- function(to, from, .strict = TRUE) {
