@@ -25,6 +25,7 @@
 #' @param x a tibble returned by `look_for()`
 #' @return a tibble data frame featuring the variable position, name and
 #' description (if it exists) in the original data frame
+#' @seealso `vignette("look_for")`
 #' @details The function looks into the variable names for matches to the
 #' keywords. If available, variable labels are included in the search scope.
 #' Variable labels of data.frame imported with \pkg{foreign} or
@@ -132,7 +133,8 @@ look_for <- function(data,
   data <- to_labelled(data)
   # search scope
   n <- names(data)
-  if (!length(n)) stop("there are no names to search in that object")
+  if (!length(n))
+    cli::cli_abort("There are no names to search in that object.")
   # search function
   keywords <- c(...)
   l <- unlist(var_label(data))
@@ -177,7 +179,7 @@ look_for <- function(data,
 
     if (details != "none") {
       data <- data %>%
-        dplyr::select(res$variable)
+        dplyr::select(dplyr::all_of(res$variable))
 
       n_missing <- function(x) {
         sum(is.na(x))
@@ -194,7 +196,7 @@ look_for <- function(data,
 
     if (details == "full") {
       data <- data %>%
-        dplyr::select(res$variable)
+        dplyr::select(dplyr::all_of(res$variable))
 
       unique_values <- function(x) {
         length(unique(x))
@@ -266,7 +268,7 @@ print.look_for <- function(x, ...) {
             !is.na(.data$value_labels) ~ .data$value_labels,
             !is.na(.data$levels) ~ .data$levels,
             !is.na(.data$range) ~ paste("range:", .data$range),
-            TRUE ~ "" # zero-width space
+            .default = "" # zero-width space
           ),
           variable = dplyr::if_else(
             duplicated(.data$pos),
@@ -350,7 +352,7 @@ print.look_for <- function(x, ...) {
       lw <- dplyr::case_when(
         w_values < lw / 2 ~ lw - w_values,
         w_label < lw / 2 ~ lw - w_label,
-        TRUE ~ trunc(lw / 2)
+        .default = trunc(lw / 2)
       )
       # a minimum of 10
       lw <- max(10, lw)
@@ -364,7 +366,7 @@ print.look_for <- function(x, ...) {
 
     print.data.frame(x, row.names = FALSE, quote = FALSE, right = FALSE)
   } else if (nrow(x) == 0) {
-    message("Nothing found. Sorry.")
+    cli::cli_alert_warning("Nothing found. Sorry.")
   } else {
     print(dplyr::as_tibble(x))
   }
@@ -406,7 +408,7 @@ convert_list_columns_to_character <- function(x) {
     dplyr::as_tibble() %>% # remove look_for class
     dplyr::mutate(
       dplyr::across(
-        where(is.list),
+        dplyr::where(is.list),
         ~ unlist(lapply(.x, paste, collapse = "; "))
       )
     )
