@@ -4,7 +4,7 @@
 #' to remove value labels, `remove_user_na()` to remove user defined missing
 #' values (*na_values* and *na_range*) and `remove_labels()` to remove all.
 #'
-#' @param x A vector or a data frame.
+#' @param x A vector, a data frame or a survey design.
 #' @param user_na_to_na Convert user defined missing values into `NA`?
 #' @param user_na_to_tagged_na Convert user defined missing values into
 #' tagged `NA`? It could be applied only to numeric vectors. Note that integer
@@ -79,13 +79,29 @@ remove_labels.data.frame <- function(x,
   x
 }
 
+#' @export
+remove_labels.survey.design <- function(x,
+                                        user_na_to_na = FALSE,
+                                        keep_var_label = FALSE,
+                                        user_na_to_tagged_na = FALSE) {
+  x$variables <- remove_labels(
+    x$variables,
+    user_na_to_na = user_na_to_na,
+    keep_var_label = keep_var_label,
+    user_na_to_tagged_na = user_na_to_tagged_na
+  )
+  x
+}
+
+#' @export
+remove_labels.svyrep.design <- remove_labels.survey.design
+
 #' @rdname remove_labels
 #' @export
 remove_var_label <- function(x) {
   UseMethod("remove_var_label")
 }
 
-
 #' @export
 remove_var_label.default <- function(x) {
   var_label(x) <- NULL
@@ -98,13 +114,21 @@ remove_var_label.data.frame <- function(x) {
   x
 }
 
+#' @export
+remove_var_label.survey.design <- function(x) {
+  x$variables <- remove_var_label(x$variables)
+  x
+}
+
+#' @export
+remove_var_label.svyrep.design <- remove_var_label.survey.design
+
 #' @rdname remove_labels
 #' @export
 remove_val_labels <- function(x) {
   UseMethod("remove_val_labels")
 }
 
-
 #' @export
 remove_val_labels.default <- function(x) {
   val_labels(x) <- NULL
@@ -117,6 +141,15 @@ remove_val_labels.data.frame <- function(x) {
   x
 }
 
+#' @export
+remove_val_labels.survey.design <- function(x) {
+  x$variables <- remove_val_labels(x$variables)
+  x
+}
+
+#' @export
+remove_val_labels.svyrep.design <- remove_val_labels.survey.design
+
 #' @rdname remove_labels
 #' @export
 remove_user_na <- function(x,
@@ -125,7 +158,6 @@ remove_user_na <- function(x,
   UseMethod("remove_user_na")
 }
 
-
 #' @export
 remove_user_na.default <- function(x,
                                    user_na_to_na = FALSE,
@@ -139,11 +171,11 @@ remove_user_na.haven_labelled_spss <- function(x,
                                                user_na_to_na = FALSE,
                                                user_na_to_tagged_na = FALSE) {
   if (user_na_to_tagged_na) {
-    if (typeof(x) == "character") {
-      stop(
-        "'user_na_to_tagged_na' cannot be used with character labelled vectors."
-      )
-    }
+    if (typeof(x) == "character")
+      cli::cli_abort(paste(
+        "{.fn user_na_to_tagged_na} cannot be used with",
+        "character labelled vectors."
+      ))
 
     val_to_tag <- x[is.na(x) & !is.na(unclass(x))] %>%
       unclass() %>%
@@ -151,18 +183,20 @@ remove_user_na.haven_labelled_spss <- function(x,
       sort()
 
     if (length(val_to_tag) > 26) {
-      warning(
-        length(val_to_tag),
-        " different user-defined missing values found in 'x'.\n",
-        "A maximum of 26 could be tagged.\n",
-        "'user_na_to_tagged_na' has been ignored.\n",
-        "'user_na_to_na = TRUE' has been used instead."
-      )
+      cli::cli_warn(c(
+        "{length(val_to_tag)} different user-defined missing
+         values found in 'x'.",
+        i = "A maximum of 26 could be tagged.",
+        "!" = "'user_na_to_tagged_na' has been ignored.",
+        i = "'user_na_to_na = TRUE' has been used instead."
+      ))
       user_na_to_na <- TRUE
     } else {
       if (is.integer(x)) {
         x <- as.double(unclass(x)) %>% copy_labels_from(x)
-        message("'x' has been converted into a double vector.")
+        cli::cli_inform(c(
+          i = "{.arg x} has been converted into a double vector."
+        ))
         val_to_tag <- as.double(val_to_tag)
       }
 
@@ -206,3 +240,18 @@ remove_user_na.data.frame <- function(x,
   )
   x
 }
+
+#' @export
+remove_user_na.survey.design <- function(x,
+                                         user_na_to_na = FALSE,
+                                         user_na_to_tagged_na = FALSE) {
+  x$variables <- remove_user_na(
+    x$variables,
+    user_na_to_na = user_na_to_na,
+    user_na_to_tagged_na = user_na_to_tagged_na
+  )
+  x
+}
+
+#' @export
+remove_user_na.svyrep.design <- remove_user_na.survey.design
