@@ -94,7 +94,7 @@ to_factor.haven_labelled <- function(
   if (explicit_tagged_na && is.double(x)) {
     new_labels <- to_character(val_labels(x), explicit_tagged_na = TRUE)
     x <- to_character(unclass(x), explicit_tagged_na = TRUE)
-    if (any(is.na(new_labels))) { # regular NA with a label
+    if (anyNA(new_labels)) { # regular NA with a label
       x[is.na(x)] <- "NA"
       new_labels[is.na(new_labels)] <- "NA"
     }
@@ -177,6 +177,7 @@ to_factor.data.frame <- function(
     decreasing = FALSE,
     labelled_only = TRUE,
     drop_unused_labels = FALSE,
+    user_na_to_na = FALSE,
     strict = FALSE,
     unclass = FALSE,
     explicit_tagged_na = FALSE,
@@ -193,6 +194,7 @@ to_factor.data.frame <- function(
       decreasing = decreasing,
       labelled_only = labelled_only,
       drop_unused_labels = drop_unused_labels,
+      user_na_to_na = user_na_to_na,
       strict = strict,
       unclass = unclass,
       explicit_tagged_na = explicit_tagged_na,
@@ -212,6 +214,7 @@ to_factor.data.frame <- function(
     decreasing = FALSE,
     labelled_only = TRUE,
     drop_unused_labels = FALSE,
+    user_na_to_na = FALSE,
     strict = FALSE,
     unclass = FALSE,
     explicit_tagged_na = FALSE,
@@ -224,6 +227,7 @@ to_factor.data.frame <- function(
       sort_levels = sort_levels,
       decreasing = decreasing,
       drop_unused_labels = drop_unused_labels,
+      user_na_to_na = user_na_to_na,
       strict = strict,
       unclass = unclass,
       explicit_tagged_na = explicit_tagged_na,
@@ -235,6 +239,45 @@ to_factor.data.frame <- function(
   x
 }
 
+
+#' @export
+#' @rdname to_factor
+to_factor.survey.design <- function(
+    x,
+    levels = c("labels", "values", "prefixed"),
+    ordered = FALSE,
+    nolabel_to_na = FALSE,
+    sort_levels = c("auto", "none", "labels", "values"),
+    decreasing = FALSE,
+    labelled_only = TRUE,
+    drop_unused_labels = FALSE,
+    user_na_to_na = FALSE,
+    strict = FALSE,
+    unclass = FALSE,
+    explicit_tagged_na = FALSE,
+    ...) {
+  x$variables <-
+    to_factor(
+      x$variables,
+      levels = levels,
+      ordered = ordered,
+      nolabel_to_na = nolabel_to_na,
+      sort_levels = sort_levels,
+      decreasing = decreasing,
+      labelled_only = labelled_only,
+      drop_unused_labels = drop_unused_labels,
+      user_na_to_na = user_na_to_na,
+      strict = strict,
+      unclass = unclass,
+      explicit_tagged_na = explicit_tagged_na,
+      ...
+    )
+  x
+}
+
+#' @export
+to_factor.svyrep.design <- to_factor.survey.design
+
 #' @rdname to_factor
 #' @description
 #' `unlabelled(x)` is a shortcut for
@@ -265,7 +308,11 @@ to_factor.data.frame <- function(
 #' }
 #' @export
 unlabelled <- function(x, ...) {
-  if (is.data.frame(x)) {
+  if (
+    is.data.frame(x) ||
+      inherits(x, "survey.design") ||
+      inherits(x, "svyrep.design")
+  ) {
     to_factor(x, strict = TRUE, unclass = TRUE, labelled_only = TRUE, ...)
   } else if (inherits(x, "haven_labelled")) {
     to_factor(x, strict = TRUE, unclass = TRUE, ...)
