@@ -1,13 +1,13 @@
 #' Get / Set value labels
 #'
-#' @param x A vector or a data.frame
+#' @param x A vector, a data frame or a survey design
 #' @param prefixed Should labels be prefixed with values?
 #' @param v A single value.
 #' @param value A named vector for `val_labels()` (see [haven::labelled()]) or
 #'   a character string for `val_label()`. `NULL` to remove the labels (except
 #'   if `null_action = "labelled"`).
-#'   For data frames, it could also be a named list with a vector of value
-#'   labels per variable.
+#'   For data frames and survey design, it could also be a named list with a
+#'   vector of value labels per variable.
 #' @param null_action,.null_action for advanced users, if `value = NULL`,
 #' unclass the vector (default) or force/keep `haven_labelled` class
 #' (if `null_action = "labelled"`)
@@ -55,6 +55,14 @@ val_labels.data.frame <- function(x, prefixed = FALSE) {
   lapply(x, val_labels, prefixed = prefixed)
 }
 
+#' @export
+val_labels.survey.design <- function(x, prefixed = FALSE) {
+  val_labels(x$variables, prefixed = prefixed)
+}
+
+#' @export
+val_labels.svyrep.design <- val_labels.survey.design
+
 #' @rdname val_labels
 #' @export
 `val_labels<-` <- function(
@@ -78,14 +86,12 @@ val_labels.data.frame <- function(x, prefixed = FALSE) {
 }
 
 #' @export
-`val_labels<-.factor` <- function(
-    x,
-    null_action = c("unclass", "labelled"),
-    value) {
+`val_labels<-.factor` <- function(x,
+                                  null_action = c("unclass", "labelled"),
+                                  value) {
   null_action <- match.arg(null_action)
-  if (!is.null(value) || null_action == "labelled") {
-    stop("Value labels cannot be applied to factors.")
-  }
+  if (!is.null(value) || null_action == "labelled")
+    cli::cli_abort("Value labels cannot be applied to factors.")
   x %>% remove_attributes("labels")
 }
 
@@ -176,21 +182,20 @@ val_labels.data.frame <- function(x, prefixed = FALSE) {
   }
 
   if (!all(names(value) %in% names(x))) {
-    missing_names <- stringr::str_c(
-      setdiff(names(value), names(x)),
-      collapse = ", "
-    )
-    stop("some variables not found in x:", missing_names)
+    missing_names <- setdiff(names(value), names(x))
+
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}} in {.arg x}."
+    ))
   }
 
   for (var in names(value)) {
     if (!is.null(value[[var]])) {
-      if (mode(x[[var]]) != mode(value[[var]])) {
-        stop("`x` and `value` must be same type",
-          call. = FALSE,
-          domain = "R-labelled"
-        )
-      }
+      if (mode(x[[var]]) != mode(value[[var]]))
+        cli::cli_abort(paste(
+          "{.arg x} ({class(x)}) and {.arg value} ({class(value)})",
+          "must be same type."
+        ))
       if (typeof(x[[var]]) != typeof(value[[var]])) {
         mode(value[[var]]) <- typeof(x[[var]])
       }
@@ -204,6 +209,18 @@ val_labels.data.frame <- function(x, prefixed = FALSE) {
   x
 }
 
+#' @export
+`val_labels<-.survey.design` <- function(
+    x,
+    null_action = c("unclass", "labelled"),
+    value) {
+
+  val_labels(x$variables, null_action = null_action) <- value
+  x
+}
+
+#' @export
+`val_labels<-.svyrep.design` <- `val_labels<-.survey.design`
 
 #' @rdname val_labels
 #' @export
@@ -213,18 +230,16 @@ val_label <- function(x, v, prefixed = FALSE) {
 
 #' @export
 val_label.default <- function(x, v, prefixed = FALSE) {
-  if (length(v) != 1) {
-    stop("`v` should be a single value", call. = FALSE, domain = "R-labelled")
-  }
+  if (length(v) != 1)
+    cli::cli_abort("{.arg v} (length: {length(v)}) should be a single value.")
   # return nothing
   NULL
 }
 
 #' @export
 val_label.haven_labelled <- function(x, v, prefixed = FALSE) {
-  if (length(v) != 1) {
-    stop("`v` should be a single value", call. = FALSE, domain = "R-labelled")
-  }
+  if (length(v) != 1)
+    cli::cli_abort("{.arg v} (length: {length(v)}) should be a single value.")
   labels <- val_labels(x, prefixed = prefixed)
   if (v %in% labels) {
     names(labels)[labels == v]
@@ -238,6 +253,14 @@ val_label.data.frame <- function(x, v, prefixed = FALSE) {
   lapply(x, val_label, v = v, prefixed = prefixed)
 }
 
+#' @export
+val_label.survey.design <- function(x, v, prefixed = FALSE) {
+  val_label(x$variables, v = v, prefixed = prefixed)
+}
+
+#' @export
+val_label.svyrep.design <- val_label.survey.design
+
 #' @rdname val_labels
 #' @export
 `val_label<-` <- function(x, v, null_action = c("unclass", "labelled"), value) {
@@ -251,13 +274,9 @@ val_label.data.frame <- function(x, v, prefixed = FALSE) {
     null_action = c("unclass", "labelled"),
     value) {
   if (length(v) != 1) {
-    stop("`v` should be a single value", call. = FALSE, domain = "R-labelled")
-  }
-  if (length(value) > 1) {
-    stop("`value` should be a single character string or NULL",
-      call. = FALSE, domain = "R-labelled"
-    )
+    cli::cli_abort("{.arg v} (length: {length(v)}) should be a single value.")
   }
+  check_string(value, allow_null = TRUE)
   names(value) <- v
   val_labels(x, null_action = null_action) <- value
   x
@@ -270,13 +289,9 @@ val_label.data.frame <- function(x, v, prefixed = FALSE) {
     null_action = c("unclass", "labelled"),
     value) {
   if (length(v) != 1) {
-    stop("`v` should be a single value", call. = FALSE, domain = "R-labelled")
-  }
-  if (length(value) > 1) {
-    stop("`value` should be a single character string or NULL",
-      call. = FALSE, domain = "R-labelled"
-    )
+    cli::cli_abort("{.arg v} (length: {length(v)}) should be a single value.")
   }
+  check_string(value, allow_null = TRUE)
 
   labels <- val_labels(x)
 
@@ -324,16 +339,7 @@ val_label.data.frame <- function(x, v, prefixed = FALSE) {
   value <- value[names(value) %in% names(x)]
 
   for (var in names(value)[]) {
-    if (!is.character(value[[var]]) && !is.null(value[[var]])) {
-      stop("`value` should contain only characters or NULL",
-        call. = FALSE, domain = "R-labelled"
-      )
-    }
-    if (length(value[[var]]) > 1) {
-      stop("`value` should contain only one string (or NULL) per variable",
-        call. = FALSE, domain = "R-labelled"
-      )
-    }
+    check_string(value[[var]], allow_null = TRUE, arg = "value")
   }
 
   for (var in names(value)) {
@@ -343,6 +349,19 @@ val_label.data.frame <- function(x, v, prefixed = FALSE) {
   x
 }
 
+#' @export
+`val_label<-.survey.design` <- function(
+    x,
+    v,
+    null_action = c("unclass", "labelled"),
+    value) {
+  val_label(x$variables, v = v, null_action = null_action) <- value
+  x
+}
+
+#' @export
+`val_label<-.svyrep.design` <- `val_label<-.survey.design`
+
 #' @rdname val_labels
 #' @export
 get_value_labels <- val_labels
@@ -411,10 +430,24 @@ set_value_labels <- function(
     .strict = TRUE,
     .null_action = c("unclass", "labelled")) {
   .null_action <- match.arg(.null_action)
-  if (!is.data.frame(.data) && !is.atomic(.data)) {
-    stop(".data should be a data.frame or a vector")
+  # survey.design case
+  if (inherits(.data, "survey.design") || inherits(.data, "svyrep.design")) {
+    .data$variables <-
+      set_value_labels(
+        .data$variables,
+        ...,
+        .labels = .labels,
+        .strict = .strict,
+        .null_action = .null_action
+      )
+    return(.data)
   }
 
+  if (!is.data.frame(.data) && !is.atomic(.data))
+    cli::cli_abort(
+      "{.arg .data} should be a data frame, a survey design or a vector."
+    )
+
   # vector case
   if (is.atomic(.data)) {
     if (!identical(.labels, NA)) {
@@ -435,11 +468,10 @@ set_value_labels <- function(
   }
   values <- rlang::dots_list(...)
   if (.strict && !all(names(values) %in% names(.data))) {
-    missing_names <- stringr::str_c(
-      setdiff(names(values), names(.data)),
-      collapse = ", "
-    )
-    stop("some variables not found in .data: ", missing_names)
+    missing_names <- setdiff(names(values), names(.data))
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}} in {.arg .data}."
+    ))
   }
 
   for (v in intersect(names(values), names(.data))) {
@@ -457,16 +489,29 @@ add_value_labels <- function(
     .strict = TRUE,
     .null_action = c("unclass", "labelled")) {
   .null_action <- match.arg(.null_action)
-  if (!is.data.frame(.data) && !is.atomic(.data)) {
-    stop(".data should be a data.frame or a vector")
+
+  # survey.design case
+  if (inherits(.data, "survey.design") || inherits(.data, "svyrep.design")) {
+    .data$variables <-
+      add_value_labels(
+        .data$variables,
+        ...,
+        .strict = .strict,
+        .null_action = .null_action
+      )
+    return(.data)
   }
 
+  if (!is.data.frame(.data) && !is.atomic(.data))
+    cli::cli_abort(
+      "{.arg .data} should be a data frame, a survey design or a vector."
+    )
+
   # vector case
   if (is.atomic(.data)) {
     values <- unlist(rlang::dots_list(...))
-    if (is.null(names(values)) || any(names(values) == "")) {
-      stop("all arguments should be named")
-    }
+    if (is.null(names(values)) || any(names(values) == ""))
+      cli::cli_abort("All arguments should be named.")
     for (v in names(values)) {
       val_label(.data, values[[v]], null_action = .null_action) <- v
     }
@@ -476,17 +521,15 @@ add_value_labels <- function(
   # data.frame case
   values <- rlang::dots_list(...)
   if (.strict && !all(names(values) %in% names(.data))) {
-    missing_names <- stringr::str_c(
-      setdiff(names(values), names(.data)),
-      collapse = ", "
-    )
-    stop("some variables not found in .data: ", missing_names)
+    missing_names <- setdiff(names(values), names(.data))
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}}  in {.arg .data}."
+    ))
   }
 
   for (v in values) {
-    if (is.null(names(v)) || any(names(v) == "")) {
-      stop("all arguments should be named vectors")
-    }
+    if (is.null(names(v)) || any(names(v) == ""))
+      cli::cli_abort("All arguments should be named vectors.")
   }
 
   for (v in intersect(names(values), names(.data))) {
@@ -506,10 +549,24 @@ remove_value_labels <- function(
     .strict = TRUE,
     .null_action = c("unclass", "labelled")) {
   .null_action <- match.arg(.null_action)
-  if (!is.data.frame(.data) && !is.atomic(.data)) {
-    stop(".data should be a data.frame or a vector")
+
+  # survey.design case
+  if (inherits(.data, "survey.design") || inherits(.data, "svyrep.design")) {
+    .data$variables <-
+      remove_value_labels(
+        .data$variables,
+        ...,
+        .strict = .strict,
+        .null_action = .null_action
+      )
+    return(.data)
   }
 
+  if (!is.data.frame(.data) && !is.atomic(.data))
+    cli::cli_abort(
+      "{.arg .data} should be a data frame, a survey design or a vector."
+    )
+
   # vector case
   if (is.atomic(.data)) {
     values <- unlist(rlang::dots_list(...))
@@ -522,11 +579,10 @@ remove_value_labels <- function(
   # data.frame case
   values <- rlang::dots_list(...)
   if (.strict && !all(names(values) %in% names(.data))) {
-    missing_names <- stringr::str_c(
-      setdiff(names(values), names(.data)),
-      collapse = ", "
-    )
-    stop("some variables not found in .data: ", missing_names)
+    missing_names <- setdiff(names(values), names(.data))
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}}  in {.arg .data}."
+    ))
   }
 
   for (v in intersect(names(values), names(.data))) {
@@ -569,19 +625,16 @@ sort_val_labels.default <- function(
 }
 
 #' @export
-sort_val_labels.haven_labelled <- function(
-    x,
-    according_to = c("values", "labels"),
-    decreasing = FALSE) {
+sort_val_labels.haven_labelled <- function(x,
+                                           according_to = c("values", "labels"),
+                                           decreasing = FALSE) {
   according_to <- match.arg(according_to)
   labels <- val_labels(x)
   if (!is.null(labels)) {
-    if (according_to == "values") {
+    if (according_to == "values")
       labels <- sort_tagged_na(labels, decreasing = decreasing)
-    }
-    if (according_to == "labels") {
+    if (according_to == "labels")
       labels <- labels[order(names(labels), decreasing = decreasing)]
-    }
     val_labels(x) <- labels
   }
   x
@@ -599,6 +652,21 @@ sort_val_labels.data.frame <- function(
   x
 }
 
+#' @export
+sort_val_labels.survey.design <- function(
+    x,
+    according_to = c("values", "labels"),
+    decreasing = FALSE) {
+  sort_val_labels(
+    x$variables,
+    according_to = according_to,
+    decreasing = decreasing
+  )
+}
+
+#' @export
+sort_val_labels.svyrep.design <- sort_val_labels.survey.design
+
 #' Turn a named vector into a vector of names prefixed by values
 #' @param x vector to be prefixed
 #' @examples
